<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation>アクセスするには管理者権限が必要です</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>この操作には管理者権限が必要です。アプリケーションを再起動し、プロンプトが表示されたらパスワードを入力してください。</translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../src/dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>ライブ環境を検出しました。変更したいシステムの root パーティションを選択してください (Linux パーティションのみ表示されます)</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>サブメニューのないシンプルなメニュー構成を使用</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>フラットメニューを使用する（サブメニューなし）</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>起動先</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>メニューを表示せずにすぐ起動する場合は「0」、そのまま待機する場合は「-1」に設定します。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>メニューのタイムアウト</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>カーネルのパラメータ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>このオプションを有効にすると、grub の起動メニューから選択したエントリは、将来のブートの新規の既定として保存されます。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>直前の起動の選択の保存を有効にします</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>UEFI の起動オプションの管理</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="181"/>
        <location filename="../src/mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>テーマの有効化</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>スプラッシュ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>メッセージ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>非常に詳細に</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>詳細に（既定の設定）</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>限定的な</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>ログの表示</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="100"/>
        <source>Still running</source>
        <translation>まだ実行中です</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <location filename="../src/mainwindow.cpp" line="410"/>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <location filename="../src/mainwindow.cpp" line="555"/>
        <location filename="../src/mainwindow.cpp" line="1399"/>
        <location filename="../src/mainwindow.cpp" line="1412"/>
        <location filename="../src/mainwindow.cpp" line="1418"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="391"/>
        <source>Installing bootsplash, please wait</source>
        <translation>bootsplash をインストールしています。お待ちください</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <location filename="../src/mainwindow.cpp" line="1188"/>
        <source>Preview is disabled because &apos;splash&apos; parameter is not present in kernel command line. To enable preview, add &apos;splash&apos; to boot parameters and reboot.</source>
        <translation>カーネルコマンドラインに  &apos;splash&apos; パラメータが存在しないため、プレビューが無効です。プレビューを有効にするには、ブートパラメータに &apos;splash&apos; を追加し再起動してください。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="161"/>
        <location filename="../src/mainwindow.cpp" line="1191"/>
        <source>Preview is disabled while running under Wayland. Please start an X11 session to preview Plymouth themes.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>Updating sources</source>
        <translation>ソースのアップデート中</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="410"/>
        <source>Could not install the bootsplash.</source>
        <translation>bootsplash をインストールできません。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="555"/>
        <source>Could not create a temporary folder</source>
        <translation>一時フォルダを作成できませんでした</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <location filename="../src/mainwindow.cpp" line="584"/>
        <source>Cannot continue</source>
        <translation>続行できません</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation>LUKS デバイスを開けません。終了します...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="585"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>chroot 環境を作成できず、起動オプションを変更できません。終了中...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="917"/>
        <location filename="../src/mainwindow.cpp" line="1315"/>
        <source>Updating configuration, please wait</source>
        <translation>設定更新中なのでお待ちください</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="988"/>
        <source>Updating initramfs...</source>
        <translation>initramfs 更新中...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1002"/>
        <location filename="../src/mainwindow.cpp" line="1330"/>
        <source>Updating grub...</source>
        <translation>grub 更新中...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1027"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1028"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1030"/>
        <source>Program for selecting common start-up choices</source>
        <translation>一般的なスタートアップを選択するためのプログラム</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1032"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1033"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1054"/>
        <source>%1 Help</source>
        <translation>%1 ヘルプ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1064"/>
        <location filename="../src/mainwindow.cpp" line="1292"/>
        <source>Running in a Virtual Machine</source>
        <translation>仮想マシンで実行中</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1065"/>
        <location filename="../src/mainwindow.cpp" line="1293"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>現在のシステムは仮想マシンで動作しています。
Plymouth のブーツプラッシュは限られた方法でしか動作しませんし、テーマをプレビューすることもできません</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1072"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth パッケージがインストールされていません</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1073"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth のパッケージは現在インストールされていません。
このまま続行してインストールしますか？</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1099"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>画像 (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>Log not found</source>
        <translation>ログが見つかりません</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>Could not find log at </source>
        <translation>ログが見つかりません</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1274"/>
        <source>Preview Unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1275"/>
        <source>Preview is not available while running under Wayland. Please start an X11 session to preview Plymouth themes.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1399"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>%1 の UUID を取得できませんでした</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1407"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>パスワードを入力し、暗号化された %1 パーティションのロックを解除してください : </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1412"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation>パスワード入力のキャンセル、または %1 が空です</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1418"/>
        <source>Could not open %1 LUKS container</source>
        <translation>%1 LUKS コンテナを開けませんでした</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1242"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="101"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>現在、処理を行っています。本当にこれを中止しますか？</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="181"/>
        <source>Live System Detected</source>
        <translation>ライブシステムを検出しました</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="183"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>現在、ライブシステムを実行しています。ライブシステムの起動オプションを変更しますか？それともインストールしたシステムの変更を行いますか？</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Live System</source>
        <translation>ライブシステム</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Installed System</source>
        <translation>インストールシステム</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <source>Failed to update package sources.</source>
        <translation>パッケージソースの更新に失敗しました。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="406"/>
        <source>Installing packages:</source>
        <translation>インストール中のパッケージ：</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="416"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="416"/>
        <source>Bootsplash installed successfully.</source>
        <translation>ブートスプラッシュのインストールが成功しました。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <source>Failed to create temporary file.</source>
        <translation>一時ファイルの生成に失敗しました。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1010"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>現在、ライブモードの &apos;toram&apos; オプションで稼働しています。永続化ファイルへ保存するかリマスターを実行しないとこの変更は保存されません。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1012"/>
        <source>Your changes have been successfully applied.</source>
        <translation>変更内容を正常に適用しました。</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1013"/>
        <source>Operation Complete</source>
        <translation>作業完了</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1098"/>
        <source>Select image to display in bootloader</source>
        <translation>ブートローダに表示するイメージを選択</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1234"/>
        <source>Boot Log</source>
        <translation>起動ログ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1281"/>
        <source>Needs reboot</source>
        <translation>再起動が必要です</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1282"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth のインストール直後なので、プレビューを表示するには再起動が必要かもしれません</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1355"/>
        <source>Click to select theme</source>
        <translation>クリックしてテーマを選択</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1366"/>
        <source>Select GRUB theme</source>
        <translation>GRUB のテーマ選択</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Program for selecting common start-up choices</source>
        <translation>一般的なスタートアップを選択するためのプログラム</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="55"/>
        <location filename="../src/about.cpp" line="64"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>root としてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
</context>
</TS>